import { APIClient, APIFetchOptions, BrowserStackOptions } from './api-client.ts';
import { components, operations } from './generated/openapi.ts';
/**
 * Represents a client for interacting with the BrowserStack JavaScript Testing API.
 * @see https://www.browserstack.com/docs/automate/javascript-testing/api
 * @public
 */
export declare class JSTestingClient extends APIClient {
    /**
     * Constructs a new instance of the JSTestingClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: BrowserStackOptions);
    /**
     * Retrieves the account status.
     *
     * @returns A Promise that resolves to the account status.
     */
    getAccountStatus(): Promise<components["schemas"]["Status"]>;
    getBrowsers<T extends true>(query?: operations["getBrowsers"]["parameters"]["query"] & {
        flat?: T;
    }, options?: APIFetchOptions<operations["getBrowsers"]>): Promise<components["schemas"]["BrowserList"]>;
    getBrowsers<T extends false>(query?: operations["getBrowsers"]["parameters"]["query"] & {
        flat?: T;
    }, options?: APIFetchOptions<operations["getBrowsers"]>): Promise<components["schemas"]["BrowserMap"]>;
    /**
     * Creates a worker for JS testing.
     *
     * @param body - The request body.
     * @param options - The API fetch options.
     * @returns A promise that resolves to the worker response.
     */
    createWorker(body: operations["createWorker"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["createWorker"]>): Promise<{
        id: number;
        url?: string | undefined;
    }>;
    /**
     * Retrieves a list of workers.
     *
     * @param options - Optional parameters for the API request.
     * @returns A promise that resolves to an array of Worker objects.
     */
    getWorkers(options?: APIFetchOptions<operations["getWorkers"]>): Promise<components["schemas"]["Worker"][]>;
    /**
     * Retrieves a worker by its ID.
     *
     * @param workerId The ID of the worker.
     * @param options Additional options for the API request.
     * @returns A Promise that resolves to the retrieved worker.
     */
    getWorker(workerId: number, options?: APIFetchOptions<operations["getWorker"]>): Promise<components["schemas"]["Worker"]>;
    /**
     * Deletes a worker by worker ID.
     *
     * @param workerId The ID of the worker to delete.
     * @param options Optional API fetch options.
     * @returns A promise that resolves when the worker is deleted.
     */
    deleteWorker(workerId: number, options?: APIFetchOptions<operations["deleteWorker"]>): Promise<{
        message: string;
        time?: number | undefined;
    }>;
    /**
     * Updates the URL of a worker.
     *
     * @param workerId - The ID of the worker.
     * @param body - The request body containing the updated URL.
     * @param options - Optional API fetch options.
     * @returns A promise that resolves with the response from the server.
     */
    updateWorkerURL(workerId: number, body: operations["updateWorkerURL"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["updateWorkerURL"]>): Promise<{
        message: string;
    }>;
    getWorkerScreenshot(workerId: number, format: "png", options?: APIFetchOptions<operations["getWorkerScreenshot"]>): Promise<ArrayBuffer>;
    getWorkerScreenshot(workerId: number, format: "json", options?: APIFetchOptions<operations["getWorkerScreenshot"]>): Promise<{
        url: string;
    }>;
    getWorkerScreenshot(workerId: number, format: "xml", options?: APIFetchOptions<operations["getWorkerScreenshot"]>): Promise<string>;
    /**
     * Awaits a worker with the specified workerId to attain "running" status.
     *
     * @param workerId - The ID of the worker to retrieve.
     * @param options - Optional API fetch options.
     * @param pollInterval - The interval (in milliseconds) at which to poll for the worker status. Default is 10000ms.
     * @returns A promise that resolves with the running worker.
     */
    ensureWorkerRunning(workerId: number, options?: APIFetchOptions<operations["getWorker"]>, pollInterval?: number): Promise<components["schemas"]["Worker"]>;
    /**
     * High-level abstraction for launching a worker-browser with the specified options.
     *
     * @param body The request body for creating the worker.
     * @param options The options for creating the worker.
     * @returns A promise that resolves to the launched worker.
     */
    launch(body: operations["createWorker"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["createWorker"]> & {
        pollInterval?: number;
    }): Promise<{
        updateURL: (url: string) => Promise<{
            message: string;
        }>;
        getScreenshot: () => Promise<ArrayBuffer>;
        getScreenshotURL: () => Promise<string>;
        terminate: () => Promise<{
            message: string;
            time?: number | undefined;
        }>;
        browser: string;
        browser_version: string;
        os: string;
        os_version: string;
        device?: string | undefined;
        real_mobile?: boolean | undefined;
        id: number;
        sessionId?: unknown;
        status?: "running" | "queue" | undefined;
        browser_url?: string | undefined;
    }>;
}
