import { APIClient, APIFetchOptions, BrowserStackOptions } from './api-client.ts';
import type { components, operations } from './generated/openapi.ts';
import type { FetchOptions } from "openapi-fetch";
/**
 * ScreenshotsClient represents a client for interacting with the BrowserStack Screenshots API.
 * @see https://www.browserstack.com/screenshots/api
 * @public
 */
export declare class ScreenshotsClient extends APIClient {
    /**
     * @internal
     */
    private static readonly jobCompleteStates;
    /**
     * Constructs a new instance of the ScreenshotsClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: BrowserStackOptions);
    /**
     * Retrieves the list of available browsers for taking screenshots.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    getBrowsers(options?: FetchOptions<operations["getScreenshotsBrowsers"]>): Promise<({
        browser: string;
        browser_version: string;
    } & {
        os: string;
        os_version: string;
        device?: string | undefined;
        real_mobile?: boolean | undefined;
    })[]>;
    /**
     * Creates a new screenshots job.
     * @param body - The request body for creating the job.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    createJob(body: operations["createScreenshotsJob"]["requestBody"]["content"]["application/json"], options?: APIFetchOptions<operations["createScreenshotsJob"]>): Promise<{
        id: string;
        job_id: string;
        callback_url?: string | undefined;
        win_res?: string | undefined;
        mac_res?: string | undefined;
        quality?: "Compressed" | "Original" | undefined;
        wait_time?: number | undefined;
        orientation?: "portrait" | "landscape" | undefined;
        screenshots?: ({
            id: string;
            state: "failed" | "done" | "processing" | "pending";
            url: string;
            os: string;
            os_version: string;
        } & ({
            device: string;
            browser?: string | undefined;
            browser_version?: string | undefined;
        } | {
            browser: string;
            browser_version: string;
        }) & {
            image_url?: string | undefined;
            thumb_url?: string | undefined;
            created_at?: string | undefined;
        })[] | undefined;
    }>;
    /**
     * Retrieves the details of a screenshots job.
     * @param jobId - The ID of the job to retrieve.
     * @param options - Optional fetch options for the request.
     * @returns A promise that resolves to the response from the API.
     */
    getJob(jobId: string, options?: APIFetchOptions<operations["getScreenshotsJob"]>): Promise<{
        id: string;
        job_id?: string | undefined;
        callback_url?: string | undefined;
        win_res?: string | undefined;
        mac_res?: string | undefined;
        quality?: "Compressed" | "Original" | undefined;
        wait_time?: number | undefined;
        orientation?: "portrait" | "landscape" | undefined;
        screenshots?: ({
            id: string;
            state: "failed" | "done" | "processing" | "pending";
            url: string;
            os: string;
            os_version: string;
        } & ({
            device: string;
            browser?: string | undefined;
            browser_version?: string | undefined;
        } | {
            browser: string;
            browser_version: string;
        }) & {
            image_url?: string | undefined;
            thumb_url?: string | undefined;
            created_at?: string | undefined;
        })[] | undefined;
        state?: "done" | "queued_all" | undefined;
    }>;
    /**
     * Tracks the progress of a screenshot job and retrieves the screenshots associated with it.
     *
     * @param jobId - The ID of the job to track.
     * @param onScreenshot - Optional callback function that will be called when a new screenshot is added to the result.
     * @param pollInterval - The interval (in milliseconds) at which the job status should be polled. Default is 10000ms.
     * @returns A promise that resolves with an array of screenshots when the job is completed.
     */
    trackJob(jobId: string, onScreenshot?: (screenshot: components["schemas"]["Screenshot"]) => void | Promise<void>, options?: APIFetchOptions<operations["getScreenshotsJob"]>, pollInterval?: number): Promise<components["schemas"]["Screenshot"][]>;
    /**
     * Launches a screenshots job with the specified parameters.
     *
     * @param body - The request body for creating the screenshots job.
     * @param onScreenshot - Optional callback function to be called when a screenshot is available.
     * @param options - Optional options for the API fetch and job tracking, including pollInterval.
     * @returns A promise that resolves to the result of the job tracking.
     */
    launch(body: operations["createScreenshotsJob"]["requestBody"]["content"]["application/json"], onScreenshot?: (screenshot: components["schemas"]["Screenshot"]) => void | Promise<void>, options?: APIFetchOptions<operations["createScreenshotsJob"]> & {
        pollInterval?: number;
    }): Promise<({
        id: string;
        state: "failed" | "done" | "processing" | "pending";
        url: string;
        os: string;
        os_version: string;
    } & ({
        device: string;
        browser?: string | undefined;
        browser_version?: string | undefined;
    } | {
        browser: string;
        browser_version: string;
    }) & {
        image_url?: string | undefined;
        thumb_url?: string | undefined;
        created_at?: string | undefined;
    })[]>;
}
